@@ -1,5 +1,5 @@
 package Module::Signature;
-$Module::Signature::VERSION = '0.61';
+$Module::Signature::VERSION = '0.62';
 
 use 5.005;
 use strict;
@@ -29,7 +29,7 @@ use Exporter;
 $SIGNATURE      = 'SIGNATURE';
 $Timeout        = $ENV{MODULE_SIGNATURE_TIMEOUT} || 3;
 $Verbose        = $ENV{MODULE_SIGNATURE_VERBOSE} || 0;
-$KeyServer      = $ENV{MODULE_SIGNATURE_KEYSERVER} || 'pgp.mit.edu';
+$KeyServer      = $ENV{MODULE_SIGNATURE_KEYSERVER} || 'pool.sks-keyservers.net';
 $KeyServerPort  = $ENV{MODULE_SIGNATURE_KEYSERVERPORT} || '11371';
 $Cipher         = $ENV{MODULE_SIGNATURE_CIPHER} || 'SHA1';
 $Preamble       = << ".";
@@ -565,7 +565,7 @@ Module::Signature - Module signature file manipulation
 
 =head1 VERSION
 
-This document describes version 0.61 of B<Module::Signature>,
+This document describes version 0.62 of B<Module::Signature>,
 released November 18, 2009.
 
 =head1 SYNOPSIS
@@ -828,7 +828,7 @@ You may add this code as F<t/0-signature.t> in your distribution tree:
                 "Next time around, consider install Module::Signature, ",
                 "so you can verify the integrity of this distribution.\n";
     }
-    elsif (!eval { require Socket; Socket::inet_aton('pgp.mit.edu') }) {
+    elsif (!eval { require Socket; Socket::inet_aton('pool.sks-keyservers.net') }) {
         print "ok 1 # skip ",
                 "Cannot connect to the keyserver\n";
     }
